@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
-our $DATE = '2015-09-23'; # DATE
-our $VERSION = '0.64'; # VERSION
+our $DATE = '2015-09-25'; # DATE
+our $VERSION = '0.65'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -107,25 +107,27 @@ sub after_gen_doc {
                 ");",
             );
             my $resdump;
-            if (exists $eg->{result}) {
-                $resdump = Data::Dump::dump($eg->{result});
-            } else {
-              GET_RESULT_BY_CALLING_FUNCTION:
-                {
-                    # XXX since we retrieve the result by calling through Riap,
-                    # the result will be json-cleaned.
-                    my %extra;
-                    if ($eg->{argv}) {
-                        $extra{argv} = $eg->{argv};
-                    } elsif($eg->{args}) {
-                        $extra{args} = $eg->{args};
-                    } else {
-                        $log->debugf("Example does not provide args/argv, skipped trying to get result from calling function");
-                        last GET_RESULT_BY_CALLING_FUNCTION;
-                    }
-                    my $res = $self->{_pa}->request(call => $self->{url}, \%extra);
-                    $resdump = Data::Dump::dump($res);
+          GET_RESULT:
+            {
+                last unless $eg->{'x.doc.show_result'} // 1;
+                if (exists $eg->{result}) {
+                    $resdump = Data::Dump::dump($eg->{result});
+                    last;
                 }
+
+                # XXX since we retrieve the result by calling through Riap,
+                # the result will be json-cleaned.
+                my %extra;
+                if ($eg->{argv}) {
+                    $extra{argv} = $eg->{argv};
+                } elsif($eg->{args}) {
+                    $extra{args} = $eg->{args};
+                } else {
+                    $log->debugf("Example does not provide args/argv, skipped trying to get result from calling function");
+                    last GET_RESULT;
+                }
+                my $res = $self->{_pa}->request(call => $self->{url}, \%extra);
+                $resdump = Data::Dump::dump($res);
             }
 
             my $status = $eg->{status} // 200;
@@ -327,7 +329,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.64 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-09-23.
+This document describes version 0.65 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-09-25.
 
 =head1 SYNOPSIS
 
